import type { OpenId4VciCredentialConfigurationsSupported, OpenId4VciCredentialConfigurationSupported, OpenId4VciCredentialSupportedWithId } from './models';
import type { AgentContext } from '@credo-ts/core';
import type { CredentialOfferFormat, KeyProofType, ProofType } from '@sphereon/oid4vci-common';
/**
 * Get all `types` from a `CredentialSupported` object.
 *
 * Depending on the format, the types may be nested, or have different a different name/type
 */
export declare function getTypesFromCredentialSupported(credentialSupported: OpenId4VciCredentialConfigurationSupported): string | string[] | undefined;
export declare function credentialConfigurationSupportedToCredentialSupported(id: string, config: OpenId4VciCredentialConfigurationSupported): OpenId4VciCredentialSupportedWithId;
export declare function credentialSupportedToCredentialConfigurationSupported(credentialSupported: OpenId4VciCredentialSupportedWithId, options?: {
    proofTypesSupported?: Record<KeyProofType, ProofType>;
}): OpenId4VciCredentialConfigurationSupported;
export declare function credentialsSupportedV13ToV11(credentialConfigurationSupported: OpenId4VciCredentialConfigurationsSupported): OpenId4VciCredentialSupportedWithId[];
export declare function credentialsSupportedV11ToV13(credentialsSupported: OpenId4VciCredentialSupportedWithId[], options?: {
    proofTypesSupported?: Record<KeyProofType, ProofType>;
}): OpenId4VciCredentialConfigurationsSupported;
/**
 * Returns all entries from the credential offer with the associated metadata resolved. For 'id' entries, the associated `credentials_supported` object is resolved from the issuer metadata.
 * For inline entries, an error is thrown.
 */
export declare function getOfferedCredentials(offeredCredentials: Array<string | CredentialOfferFormat>, allCredentialsSupported: OpenId4VciCredentialSupportedWithId[] | OpenId4VciCredentialConfigurationsSupported, options?: {
    proofTypesSupported?: Record<KeyProofType, ProofType>;
}): OpenId4VciCredentialConfigurationsSupported;
export declare const getProofTypesSupported: (agentContext: AgentContext) => {
    jwt: {
        proof_signing_alg_values_supported: string[];
    };
    cwt: {
        proof_signing_alg_values_supported: never[];
    };
    ldp_vp: {
        proof_signing_alg_values_supported: never[];
    };
};
